#include <cvidef.h>

/*	Magna-Power Electronics, Inc. Series DC Power Supplies					*/ 
/*	Include file for the A & D series										*/ 


#ifndef __mpexxx_HEADER_
#define __mpexxx_HEADER_

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*----------------------------------------------------------------------------------
						instr specific error codes
  ----------------------------------------------------------------------------------*/
#define VI_WARNING_INSTR_OFFSET			(0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET			(_VI_ERROR + VI_WARNING_INSTR_OFFSET)

#define MPEXXX_ERR_DRIVER_DATA			(VI_ERROR_INSTR_OFFSET + 0x1L)

/*----------------------------------------------------------------------------------
						instr specific warning codes
  ----------------------------------------------------------------------------------*/
#define MPEXXX_WARNING_MODEL_DATA		(VI_WARNING_INSTR_OFFSET + 0x1L)
#define MPEXXX_WARNING_INVALID_RESP		(VI_WARNING_INSTR_OFFSET + 0x2L)

/*----------------------------------------------------------------------------------
						system routines for mpe instrument							
  ----------------------------------------------------------------------------------*/
/*	mpexxx_init
		inits visa, lmt struct & resets if desirable
		resourceString	-	descriptor for comm bus
		ID_Query		-	id query discrete
		Reset			-	reset discrete
		vi				-	ptr to session handle */
ViStatus _VI_FUNC mpexxx_init (ViRsrc resourceString, ViBoolean ID_Query, ViBoolean Reset,
							   ViSession *vi);

/*	mpexxx_close
		closes session and frees memory
		vi	-	specific session	*/
ViStatus _VI_FUNC mpexxx_close (ViSession vi);

/*----------------------------------------------------------------------------------
						exported cmds for mpe instrument							
  ----------------------------------------------------------------------------------*/

/*	mpexxx_conf
		performs complete set point settings
		vi				-	session handle
		remoteSense		-	remote sense discrete
		internalControl	-	internal control discrete
		externalControl	-	external control discrete
		interlock		-	interlock discrete	*/
ViStatus _VI_FUNC mpexxx_conf (ViSession vi, ViBoolean remoteSense, ViBoolean internalControl,
                           ViBoolean externalControl, ViBoolean interlock);

/*	mpexxx_set_rem_sen
		sets the state of remote sense
		vi			-	session handle
		remoteSense	-	remote sense discrete	*/
ViStatus _VI_FUNC mpexxx_set_rem_sen (ViSession vi, ViBoolean remoteSense);

/*	mpexxx_get_rem_sen
		gets the state of external control
		vi			-	session handle
		remoteSense	-	ptr remote sense discrete	*/
ViStatus _VI_FUNC mpexxx_get_rem_sen (ViSession vi, ViBoolean *remoteSense);

/*	mpexxx_set_int_ctrl
		sets the state of the internal control
		vi				-	session handle
		internalControl	-	internal control discrete	*/
ViStatus _VI_FUNC mpexxx_set_int_ctrl (ViSession vi, ViBoolean internalControl);

/*	mpexxx_get_int_ctrl
		gets the state of internal control
		vi				-	session handle
		internalControl	-	ptr internal control discrete	*/
ViStatus _VI_FUNC mpexxx_get_int_ctrl (ViSession vi, ViBoolean *internalControl);

/*	mpexxx_set_ext_ctrl
		sets the state of the external control
		vi				-	session handle
		externalControl	-	external control state	*/
ViStatus _VI_FUNC mpexxx_set_ext_ctrl (ViSession vi, ViBoolean externalControl);

/*	mpexxx_get_ext_ctrl
		gets the state of external control
		vi				-	session handle
		externalControl	-	ptr discrete for external control state	*/
ViStatus _VI_FUNC mpexxx_get_ext_ctrl (ViSession vi, ViBoolean *externalControl);

/*	mpexxx_set_interlock
		sets the state of the interlock
		vi			-	session handle
		interlock	-	interlock discrete	*/
ViStatus _VI_FUNC mpexxx_set_interlock (ViSession vi, ViBoolean interlock);

/*	mpexxx_get_interlock
		sets the identification string
		vi			-	session handle
		interlock	-	ptr to state of interlock	*/
ViStatus _VI_FUNC mpexxx_get_interlock (ViSession vi, ViBoolean *interlock);

/*	mpexxx_set_pnts_xxd
		sets the set points
		vi		-	session handle
		voltage	-	voltage setting
		current	-	current setting
		OVP		-	over-voltage trip setting
		OCP		-	over-current trip setting
		period	-	period setting	*/
ViStatus _VI_FUNC mpexxx_set_pnts_xxd (ViSession vi, ViReal64 voltage, ViReal64 current, 
								   ViReal64 OVP, ViReal64 OCP, ViReal64 period);

/*	mpexxx_set_pnts_xxa
		sets the set points
		vi		-	session handle
		voltage	-	voltage setting
		current	-	current setting
		OVP		-	over-voltage trip setting
		OCP		-	over-current trip setting	*/
ViStatus _VI_FUNC mpexxx_set_pnts_xxa (ViSession vi, ViReal64 voltage, ViReal64 current, 
								   ViReal64 OVP, ViReal64 OCP);

/*	mpexxx_set_volt_curr
		sets voltage and current of supply
		vi		-	session handle
		voltage	-	voltage setting
		current	-	current setting	*/
ViStatus _VI_FUNC mpexxx_set_volt_curr (ViSession vi, ViReal64 voltage,
                                    ViReal64 current);

/*	mpexxx_set_ovp_ocp
		sets over-voltage and over-current trip of supply
		vi	-	session handle
		OVP	-	over-voltage trip setting
		OCP	-	over-current trip setting	*/
ViStatus _VI_FUNC mpexxx_set_ovp_ocp (ViSession vi, ViReal64 OVP, ViReal64 OCP);

/*	mpexxx_set_volt
		sets voltage of supply
		vi		-	session handle
		voltage	-	voltage setting	*/
ViStatus _VI_FUNC mpexxx_set_volt (ViSession vi, ViReal64 voltage);

/*	mpexxx_get_volt
		gets voltage of supply
		vi		-	session handle
		voltage	-	ptr to voltage setting	*/
ViStatus _VI_FUNC mpexxx_get_volt (ViSession vi, ViReal64 *voltage);

/*	mpexxx_set_curr
		sets the set point for current
		vi		-	session handle
		current	-	current set point value	*/
ViStatus _VI_FUNC mpexxx_set_curr (ViSession vi, ViReal64 current);

/*	mpexxx_get_curr
		returns the set point for current
		vi		-	session handle
		amps	-	ptr used to return current	*/
ViStatus _VI_FUNC mpexxx_get_curr (ViSession vi, ViReal64 *current);

/*	mpexxx_set_ovp
		returns the set point for over-voltage
		vi	-	session handle
		OVP	-	value to set over-voltage trip	*/
ViStatus _VI_FUNC mpexxx_set_ovp (ViSession vi, ViReal64 OVP);

/*	mpexxx_Get_Ovp
		returns the set point for over-voltage
		vi	-	session handle
		OVP	-	ptr used to return over-voltage	*/
ViStatus _VI_FUNC mpexxx_get_ovp (ViSession vi, ViReal64 *OVP);

/*	mpexxx_set_ocp
		sets the set point for over-current
		vi	-	session handle
		OVP	-	value to set over-current trip	*/
ViStatus _VI_FUNC mpexxx_set_ocp (ViSession vi, ViReal64 OCP);

/*	mpexxx_Get_Ocp
		returns the set point for over-current
		vi	-	session handle
		ocp	-	ptr used to return over-current	*/
ViStatus _VI_FUNC mpexxx_get_ocp (ViSession vi, ViReal64 *OCP);

/*	mpexxx_set_period
		sets the set point for period
		vi		-	session handle
		period	-	value of period	*/
ViStatus _VI_FUNC mpexxx_set_period (ViSession vi, ViReal64 period);

/*	mpexxx_get_period
		gets current period of supply
		vi		-	session handle
		period	-	ptr to period	*/
ViStatus _VI_FUNC mpexxx_get_period (ViSession vi, ViReal64 *period);

/*	mpexxx_set_mem
		sets the current memory location
		vi	-	session handle
		mem	-	value for memory location	*/
ViStatus _VI_FUNC mpexxx_set_mem (ViSession vi, ViInt16 mem);

/*	mpexxx_get_mem
		gets current memory location
		vi	-	session handle
		mem	-	ptr to value for memory location	*/
ViStatus _VI_FUNC mpexxx_get_mem (ViSession vi, ViInt16 *mem);

/*	mpexxx_set_arm
		enables/disables arm of supply
		vi	-	session handle
		arm	-	discrete for arm setting	*/
ViStatus _VI_FUNC mpexxx_set_arm (ViSession vi, ViBoolean arm);

/*	mpexxx_get_arm
		gets the state of the arm setting
		vi	-	session handle
		arm	-	ptr to discrete for arm setting	*/
ViStatus _VI_FUNC mpexxx_get_arm (ViSession vi, ViBoolean *arm);

/*	mpexxx_set_outp
		enables/disables the output of the supply
		vi			-	session handle
		powerState	-	discrete for output of the power supply	*/
ViStatus _VI_FUNC mpexxx_set_outp (ViSession vi, ViBoolean powerState);

/*	mpexxx_clr_outp
		clears the alarm state
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_clr_outp (ViSession vi);

/*	mpexxx_get_outp
		gets the output state of supply
		vi			-	session handlehandle
		powerState	-	ptr to the output state	*/
ViStatus _VI_FUNC mpexxx_get_outp (ViSession vi, ViBoolean *powerState);

/*	mpexxx_set_trigger
		sets the trigger state of supply
		vi					-	session handle
		triggerVoltage		-	value for trigger voltage setting
		triggerCurrent		-	value for trigger current setting
		initiateContinuous	-	value for initiate continous	*/
ViStatus _VI_FUNC mpexxx_set_trigger (ViSession vi, ViReal64 triggerVoltage,
                                  ViReal64 triggerCurrent, ViBoolean initiateContinuous);

/*	mpexxx_abort
		sends an abort to stop current triggering
		vi	-	session handlehandle	*/
ViStatus _VI_FUNC mpexxx_abort (ViSession vi);

/*	mpexxx_set_trig_volt
		sets the trigger voltage for the supply
		vi				-	session handle
		triggerVoltage	-	value for voltage trigger setting	*/
ViStatus _VI_FUNC mpexxx_set_trig_volt (ViSession vi, ViReal64 triggerVoltage);

/*	mpexxx_get_trig_volt
		gets the trigger voltage for the supply
		vi				-	session handle
		triggerVoltage	-	ptr to value for voltage trigger setting	*/
ViStatus _VI_FUNC mpexxx_get_trig_volt (ViSession vi, ViReal64 *triggerVoltage);

/*	mpexxx_set_trig_curr
		sets the trigger current for the supply
		vi				-	session handle
		triggerCurrent	-	value for current trigger setting	*/
ViStatus _VI_FUNC mpexxx_set_trig_curr (ViSession vi, ViReal64 triggerCurrent);

/*	mpexxx_get_trig_curr
		gets the trigger current for the supply
		vi				-	session handle
		triggerCurrent	-	ptr to value for current trigger setting	*/
ViStatus _VI_FUNC mpexxx_get_trig_curr (ViSession vi, ViReal64 *triggerCurrent);

/*	mpexxx_trig_imm
		sends a trigger immediate
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_trig_imm (ViSession vi);

/*	mpexxx_get_syst_err
		retrieves error messages from instr
		vi				-	session handle
		errorMessage	-	buf for error message	*/
ViStatus _VI_FUNC mpexxx_get_syst_err (ViSession vi, ViChar errorMessage[]);

/*	mpexxx_get_syst_vers
		retrieves error version from instr
		vi				-	session handle
		versionMessage	-	buf for version message	*/
ViStatus _VI_FUNC mpexxx_get_syst_vers (ViSession vi, ViChar versionMessage[]);

/*	mpexxx_set_init_imm
		sends an initiate immediate
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_set_init_imm (ViSession vi);

/*	mpexxx_set_init_cont
		sets the initiate sub-system into continous mode
		vi					-	session handle
		initiateContinuous	-	discrete for initiate continous state	*/
ViStatus _VI_FUNC mpexxx_set_init_cont (ViSession vi, ViBoolean initiateContinuous);

/*	mpexxx_get_init_cont
		retrieves the state of initiate continous
		vi	-	session handle
		initiateContinuous	-	ptr to discrete for initiate continous state	*/
ViStatus _VI_FUNC mpexxx_get_init_cont (ViSession vi, ViBoolean *initiateContinuous);

/*	mpexxx_get_stat_oper
		returns the operation register
		vi					-	session handle
		operationRegister	-	ptr to returned value	*/
ViStatus _VI_FUNC mpexxx_get_stat_oper (ViSession vi, ViInt16 *operationRegister);

/*	mpexxx_get_stat_ques
		returns the questionable register
		vi						-	session handle
		questionableRegister	-	ptr to returned value	*/
ViStatus _VI_FUNC mpexxx_get_stat_ques (ViSession vi, ViInt16 *questionableRegister);

/*	mpexxx_get_meas_volt
		returns the output voltage of the supply
		vi		-	session handle
		voltage	-	ptr to the value	*/
ViStatus _VI_FUNC mpexxx_get_meas_volt (ViSession vi, ViReal64 *voltage);

/*	mpexxx_Get_Meas_Curr
		returns the output current of the supply
		vi		-	session handle
		current	-	ptr to the value	*/
ViStatus _VI_FUNC mpexxx_get_meas_curr (ViSession vi, ViReal64 *current);

/*	mpexxx_set_cal_idn
		sets the identification string of the supply
		vi						-	session handle
		identificationString	-	buf for id string	*/
ViStatus _VI_FUNC mpexxx_set_cal_idn (ViSession vi, ViChar identificationString[]);

/*	mpexxx_get_cal_idn
		gets the identification string of the supply
		vi						-	session handle
		identificationString	-	buf for id string	*/
ViStatus _VI_FUNC mpexxx_get_cal_idn (ViSession vi, ViChar identificationString[]);

/*	mpexxx_cal_pwd
		transmitts password for cal
		vi			-	session handle
		password	-	password value	*/
ViStatus _VI_FUNC mpexxx_cal_pwd (ViSession vi, ViInt16 password);

/*	mpexxx_set_cal_pot
		updates a pot setting - only works if cal sub-system is intiated
		vi	-	session handle
		pot		-	pot number
		val		-	pot value	*/
ViStatus _VI_FUNC mpexxx_set_cal_pot (ViSession vi, ViInt16 pot, ViInt16 value);

/*	mpexxx_get_cal_pot
		returns a pot setting
		vi	-	session handle
		pot	-	pot number
		val	-	ptr to pot value	*/
ViStatus _VI_FUNC mpexxx_get_cal_pot (ViSession vi, ViInt16 pot, ViInt16 *value);

/*	mpexxx_set_cal_defs
		sets defaults for supply - only works if cal sub-system is intiated
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_set_cal_defs (ViSession vi);

/*	mpexxx_cal_end
		stops cal sub-system
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_cal_end (ViSession vi);

/*	mpexxx_get_vscl
		returns the voltage scale for the supply
		vi				-	session handle
		voltageScale	-	ptr used to return voltage scale	*/
ViStatus _VI_FUNC mpexxx_get_vscl (ViSession vi, ViReal64 *voltageScale);

/*	mpexxx_get_iscl
		returns the current scale for the supply
		vi				-	session handle
		currentScale	-	ptr used to return current scale	*/
ViStatus _VI_FUNC mpexxx_get_iscl (ViSession vi, ViReal64 *currentScale);

/*	mpexxx_set_modulation_table
		sets the modulation voltage and factor for a specified row
		vi					-	session handle
		row					-	value oflocation in table
		modulationVoltage	-	value of modulation input voltage
		modulationFactor	-	value of scaling factor for modulation	*/
ViStatus _VI_FUNC mpexxx_mpexxx_set_modulation_table (ViSession vi, ViInt16 row, ViReal64 modulationVoltage,
                                                      ViReal64 modulationFactor);

/*	mpexxx_get_modulation_table
		returns the modulation voltage and factor for a specified row
		vi					-	session handle
		row					-	value of location in table
		modulationVoltage	-	ptr to modulation input voltage
		modulationFactor	-	ptr to scaling factor for modulation	*/
ViStatus _VI_FUNC mpexxx_mpexxx_get_modulation_table (ViSession vi, ViInt16 row, ViReal64 *modulationVoltage,
                                                      ViReal64 *modulationFactor);

/*	mpexxx_set_modulation_table_info
		sets the selected output modulate & modulation type
		vi				-	session handle
		controlInput	-	value of table type (none, voltage & current)
		modulationType	-	value of modulation type (multiplication & addition)	*/
ViStatus _VI_FUNC mpexxx_mpexxx_set_modulation_type (ViSession vi, ViInt16 controlInput,
                                                     ViInt16 modulationType);

/*	mpexxx_mpexxx_get_modulation_type
		returns the selected output modulate & modulation type
		vi				-	session handle
		controlInput	-	ptr to table type (none, voltage & current)
		modulationType	-	ptr to modulation type (multiplication & addition)	*/
ViStatus _VI_FUNC mpexxx_mpexxx_get_modulation_type (ViSession vi, ViInt16 *controlInput,
                                                     ViInt16 *modulationType);

/*----------------------------------------------------------------------------------
						IEEE routines for mpe instrument							
  ----------------------------------------------------------------------------------*/

/*	mpexxx_Cmd_CLS
		clears the interface
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_set_cls (ViSession vi);

/*	mpexxx_set_ese
		sets the event status enable register
		vi		-	session handle
		value	-	val to set the event status enable register	*/
ViStatus _VI_FUNC mpexxx_set_ese (ViSession vi, ViInt16 value);

/*	mpexxx_get_ese
		retrieves the event status register
		vi		-	session handle
		value	-	ptr tyo value of event status reg	*/
ViStatus _VI_FUNC mpexxx_get_ese (ViSession vi, ViInt16 *value);

/*	mpexxx_get_esr
		returns the event status register
		vi		-	session handle
		value	-	ptr to event status register value	*/
ViStatus _VI_FUNC mpexxx_get_esr (ViSession vi, ViInt16 *value);

/*	mpexxx_get_idn
		returns the identification string
		vi						-	session handle
		identificationString	-	id buffer	*/
ViStatus _VI_FUNC mpexxx_get_idn (ViSession vi, ViChar identificationString[]);

/*	mpexxx_set_rcl
		recalls the specified mem state
		vi		-	session handle
		value	-	mem address value	*/
ViStatus _VI_FUNC mpexxx_set_rcl (ViSession vi, ViInt16 value);

/*	mpexxx_Cmd_RST
		resets system according to manual
		vi	-	session handle	*/
ViStatus _VI_FUNC mpexxx_set_rst (ViSession vi);

/*	mpexxx_Cmd_SAV
		saves to a specified state
		vi		-	session handle
		value	-	memory location to save	*/
ViStatus _VI_FUNC mpexxx_set_sav (ViSession vi, ViInt16 value);

/*	mpexxx_Cmd_SRE
		sets the service request register
		vi		-	session handle
		value	-	value to set the service request register	*/
ViStatus _VI_FUNC mpexxx_set_sre (ViSession vi, ViInt16 value);

/*	mpexxx_get_sre
		returns the service request enable register
		vi		-	session handle
		value	-	ptr to service request enable register value	*/
ViStatus _VI_FUNC mpexxx_get_sre (ViSession vi, ViInt16 *value);

/*	mpexxx_get_stb
		returns the service byte register
		vi		-	session handle
		value	-	ptr to status byte register value	*/
ViStatus _VI_FUNC mpexxx_get_stb (ViSession instrumentHandle, ViInt16 *value);

/*	mpexxx_reset
		resets instrument to power on state
		vi		-	session handle	*/
ViStatus _VI_FUNC mpexxx_reset (ViSession vi);

/*	mpexxx_self_test
		performs self test - no self test (conform pnp spec
		vi				-	session handle
		errorCode		-	ptr to error code
		errorMessage	-	buf for error message	*/
ViStatus _VI_FUNC mpexxx_self_test (ViSession vi, ViInt32 *Error_Code,
									ViChar Error_Message[]);

/*	mpexxx_error_query
		retrieve error buffer
		vi				-	session handle
		errorCode		-	ptr to error code
		errorMessage	-	buf for error message	*/
ViStatus _VI_FUNC mpexxx_error_query (ViSession vi, ViInt32 *Error_Code,
										ViChar Error_Message[]);

/*	mpexxx_revision_query
		returns the queries
		vi							-	session handle
		instrumentDriverRevision	-	buf for driver rev
		firmwareRevision			-	buf for firmware rev	*/
ViStatus _VI_FUNC mpexxx_revision_query (ViSession vi, ViChar instrumentDriverRevision[],
										 ViChar firmwareRevision[]);

/*	mpexxx_error_message
		returns the service byte register
		vi			-	session handle
		statusCode	-	status code
		message		-	buf for error message	*/
ViStatus _VI_FUNC mpexxx_error_message (ViSession vi, ViStatus statusCode, ViChar message[]);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif
